calc_warming_no_coal: Calculate the impact of CO2 as it increases the warming of...

Description Usage Arguments Value Author(s)

Description

Calculate the impact of CO2 as it increases the warming of the planet if we replaced coal with renewable energy sources (assume no emissions)

Usage

1

Arguments

ghg

is the data frame with all of the CO2 emissions from all fuel types and industries

Value

amount of planetary warming from CO2 emissions; for every 10 tons of CO2 emitted, the planet warms by 0.1 degrees Celsius.

Author(s)

Joslyn Fritz and Angie Bouche


angiebouche/ESM_262_Assignment_5 documentation built on June 14, 2019, 3:25 p.m.